import cosm.*;
import processing.xml.*;
import oscP5.*;
import netP5.*;

//Solar Wind Speed / 350-560
DataIn solarFeed;
//River levels / 2.33-2.66
DataIn riverFeed;
//Air quality / 20-40
DataIn airFeed;

OscP5 oscP5;
NetAddress myRemoteLocation;

String url;
XMLElement rss;
String lastEntry;
int savedTime, totalTime;
float earthquakeIncomingValue, solarIncomingValue, riverIncomingValue, airIncomingValue, 
tweetsIncomingValue;

String apiKey = "c1kLQY2C6Gu0w7Pyu6NeW3Ib2xaSAKx0ckFNWm80RzFJcz0g";
String solarID = "256";
String riverID = "88615";
String airID = "57363";

Twitter myTwitter;
//From 0-50

void setup() {
  frameRate(10);
  url = "http://bbnet.gein.noa.gr/rss/automatic_events_24h.xml";
  rss = new XMLElement(this, url);
  readXML();
  savedTime = millis();
  totalTime = 30000;

  solarFeed = new DataIn(this, apiKey, solarID);
  riverFeed = new DataIn(this, apiKey, riverID);
  airFeed = new DataIn(this, apiKey, airID);

  requestCosmData();

  oscP5 = new OscP5(this, 7401);
  myRemoteLocation = new NetAddress("127.0.0.1", 7400);
}

void draw() {
  //background(0);
  if (timerFinished()) {
    savedTime = millis();  
    readXML();
    requestCosmData();
    getTweets();
  }

  OscMessage earthquakeMessage = new OscMessage ("/1/earthquakeData");
  earthquakeMessage.add(earthquakeIncomingValue);
  println("Earthquake: " + earthquakeIncomingValue);
  oscP5.send(earthquakeMessage, myRemoteLocation);

  OscMessage solarMessage = new OscMessage ("/1/solarData");
  solarMessage.add(solarIncomingValue);
  println("Solar: " + solarIncomingValue);
  oscP5.send(solarMessage, myRemoteLocation);

  OscMessage riverMessage = new OscMessage ("/1/riverData");
  riverMessage.add(riverIncomingValue);
  println("River: " + riverIncomingValue);  
  oscP5.send(riverMessage, myRemoteLocation);

  OscMessage airMessage = new OscMessage ("/1/airData");
  airMessage.add(airIncomingValue);
  println("Air: " + airIncomingValue);
  oscP5.send(airMessage, myRemoteLocation);

  OscMessage tweetsMessage = new OscMessage ("/1/tweetsData");
  tweetsMessage.add(tweetsIncomingValue);
  println("Tweets: " + tweetsIncomingValue); 
  oscP5.send(tweetsMessage, myRemoteLocation);
}

void readXML() {
  // Get title of each element
  XMLElement[] titleXMLElements = rss.getChildren("channel/item/title");
  for (int i = 0; i < titleXMLElements.length; i++) {
    String title = titleXMLElements[i].getContent();
    //println(i + ": " + title);
    lastEntry = titleXMLElements[0].getContent();
    String[] splitList = split(lastEntry, ' ');
    //splitList[0];
    String numberFromList = splitList[1];
    earthquakeIncomingValue = float(numberFromList);
  }
  //println(earthquakeVal);
}

void requestCosmData() {
  solarFeed.connect(); //send pull request   
  riverFeed.connect(); //send pull request     
  airFeed.connect(); //send pull request       

    solarIncomingValue = solarFeed.getValue(0); //getValue by stream number (int)
  riverIncomingValue = riverFeed.getValue(1); //getValue by stream number (int)
  airIncomingValue = airFeed.getValue(0); //getValue by stream number (int)
  //println(solarVar);
  //println(riverVar);
  //println(airVar);
}

void getTweets() {
  myTwitter = new Twitter();
  try {
    Query query = new Query("life");
    query.setRpp((int)random(50));
    QueryResult result = myTwitter.search(query);
    ArrayList tweets = (ArrayList) result.getTweets();
    for (int i = 0; i < tweets.size(); i++) {
      Tweet t = (Tweet) tweets.get(i);
      tweetsIncomingValue = i;
    }
  }
  catch(TwitterException te) {
    println("couldn't connect:" + te);
  }  
  //println("Tweet counts: " + tweetCounts);
  delay(2000);
}

boolean timerFinished() {
  int passedTime = millis() - savedTime;
  if (passedTime > totalTime) {
    return true;
  } 
  else {
    return false;
  }
}

